@@ -76,6 +76,13 @@ def main():
         help=t('cli_verbose_help')
     )
     
+    parser.add_argument(
+        "--base-url",
+        dest="base_url",
+        default=None,
+        help=t('cli_base_url_help')
+    )
+    
     parser.add_argument(
         "--serve",
         action="store_true",
@@ -114,7 +121,8 @@ def main():
                 doc_language=args.doc_language,
                 ui_language=getattr(args, 'ui_language', None),
                 recursion_limit=args.recursion_limit,
-                verbose=args.verbose
+                verbose=args.verbose,
+                base_url=getattr(args, 'base_url', None)
             )
         
     except KeyboardInterrupt:
@@ -136,7 +144,7 @@ def main():
             print(f"\n❌ {t('error_authentication_failed', default='Authentication Failed')}", file=sys.stderr)
             print(f"\n{t('error_auth_cause', default='This error occurs when your Anthropic API key is not properly configured.')}", file=sys.stderr)
             print(f"\n🔧 {t('error_auth_solution', default='Quick Fix:')}", file=sys.stderr)
-            print(f"   export ANTHROPIC_API_KEY='your-api-key-here'", file=sys.stderr)
+            print(f"   export ANTHROPIC_AUTH_TOKEN='your-api-key-here'", file=sys.stderr)
             print(f"\n📚 {t('error_auth_help', default='For detailed help, visit:')} https://console.anthropic.com", file=sys.stderr)
 
             if args.verbose:
