@@ -15,6 +15,7 @@ MESSAGES: Dict[str, Dict[str, str]] = {
         'output_dir': '📝 Output Directory',
         'doc_language': '🌍 Document Language',
         'ui_language': '💬 UI Language',
+        'api_base_url': '🔗 API Base URL',
         'auto_detected': 'Auto-detected',
         'user_specified': 'User-specified',
         'loading_prompt': '✓ Loaded system prompt (injected working directory, output directory, and document language)',
@@ -61,13 +62,14 @@ Supported languages:
   
 Environment variables:
   OPENAI_API_KEY     OpenAI API key (if using OpenAI models)
-  ANTHROPIC_API_KEY  Anthropic API key (if using Claude)
+  ANTHROPIC_AUTH_TOKEN  Anthropic API auth token (if using Claude)
         ''',
         'cli_working_dir_help': 'Project working directory (default: current directory)',
         'cli_output_dir_help': 'Documentation output directory (default: docs)',
         'cli_language_help': 'Documentation language (default: auto-detect). Supports: Chinese, English, Japanese, Korean, French, German, Spanish, Russian',
         'cli_ui_language_help': 'User interface language (default: auto-detect). Options: en, zh',
         'cli_verbose_help': 'Show detailed debug logs',
+        'cli_base_url_help': 'Custom Anthropic API base URL (default: https://api.anthropic.com)',
         'cli_serve_help': 'Start web server to browse documentation',
         'cli_missing_docs': 'Error: Documentation directory "{path}" does not exist',
         'cli_serve_hint': 'Please generate documentation first using: codeviewx -w /path/to/project',
@@ -81,17 +83,15 @@ Environment variables:
         'error_directory_not_exist': 'Error: Directory does not exist: {path}',
 
         # API key and authentication errors
-        'error_api_key_missing': 'ANTHROPIC_API_KEY environment variable not found',
+        'error_api_key_missing': 'ANTHROPIC_AUTH_TOKEN environment variable not found',
         'error_api_key_solution': '''To fix this issue:
 1. Get your API key from https://console.anthropic.com
 2. Set the environment variable:
-   export ANTHROPIC_API_KEY='your-api-key-here'
+   export ANTHROPIC_AUTH_TOKEN='your-api-key-here'
 3. Or add it to your shell profile (~/.bashrc, ~/.zshrc, etc.)
 4. Restart your terminal or run: source ~/.bashrc''',
-        'error_api_key_invalid': 'ANTHROPIC_API_KEY appears to be invalid (too short)',
-        'error_api_key_check': 'Please check that your API key is correct and starts with \'sk-ant-api\'',
-        'error_api_key_format': 'ANTHROPIC_API_KEY format appears incorrect',
-        'error_api_key_format_expected': 'Expected format: sk-ant-api...',
+        'error_api_key_invalid': 'ANTHROPIC_AUTH_TOKEN appears to be invalid (too short)',
+        'error_api_key_check': 'Please check that your API key is correct',
         'api_help_header': '🔗 Need help?',
         'api_help_get_key': '• Get your API key: https://console.anthropic.com',
         'api_help_docs': '• View documentation: https://docs.anthropic.com',
@@ -129,6 +129,7 @@ Environment variables:
         'output_dir': '📝 输出目录',
         'doc_language': '🌍 文档语言',
         'ui_language': '💬 界面语言',
+        'api_base_url': '🔗 API 基础 URL',
         'auto_detected': '自动检测',
         'user_specified': '用户指定',
         'loading_prompt': '✓ 已加载系统提示词（已注入工作目录、输出目录和文档语言）',
@@ -175,13 +176,14 @@ Environment variables:
   
 环境变量:
   OPENAI_API_KEY     OpenAI API 密钥（如使用 OpenAI 模型）
-  ANTHROPIC_API_KEY  Anthropic API 密钥（如使用 Claude）
+  ANTHROPIC_AUTH_TOKEN  Anthropic API 密钥（如使用 Claude）
         ''',
         'cli_working_dir_help': '项目工作目录（默认：当前目录）',
         'cli_output_dir_help': '文档输出目录（默认：docs）',
         'cli_language_help': '文档语言（默认：自动检测）。支持：Chinese, English, Japanese, Korean, French, German, Spanish, Russian',
         'cli_ui_language_help': '用户界面语言（默认：自动检测）。选项：en, zh',
         'cli_verbose_help': '显示详细的调试日志',
+        'cli_base_url_help': '自定义 Anthropic API 基础 URL（默认: https://api.anthropic.com）',
         'cli_serve_help': '启动 Web 服务器浏览文档',
         'cli_missing_docs': '错误: 文档目录 "{path}" 不存在',
         'cli_serve_hint': '请先使用以下命令生成文档: codeviewx -w /path/to/project',
@@ -195,17 +197,15 @@ Environment variables:
         'error_directory_not_exist': '错误: 目录不存在: {path}',
 
         # API key and authentication errors
-        'error_api_key_missing': '找不到环境变量 ANTHROPIC_API_KEY',
+        'error_api_key_missing': '找不到环境变量 ANTHROPIC_AUTH_TOKEN',
         'error_api_key_solution': '''解决方案:
 1. 从 https://console.anthropic.com 获取您的 API 密钥
 2. 设置环境变量:
-   export ANTHROPIC_API_KEY='your-api-key-here'
+   export ANTHROPIC_AUTH_TOKEN='your-api-key-here'
 3. 或将其添加到 Shell 配置文件 (~/.bashrc, ~/.zshrc 等)
 4. 重启终端或运行: source ~/.bashrc''',
-        'error_api_key_invalid': 'ANTHROPIC_API_KEY 似乎无效（太短）',
-        'error_api_key_check': '请检查您的 API 密钥是否正确，且以 \'sk-ant-api\' 开头',
-        'error_api_key_format': 'ANTHROPIC_API_KEY 格式似乎不正确',
-        'error_api_key_format_expected': '预期格式: sk-ant-api...',
+        'error_api_key_invalid': 'ANTHROPIC_AUTH_TOKEN 似乎无效（太短）',
+        'error_api_key_check': '请检查您的 API 密钥是否正确',
         'api_help_header': '🔗 需要帮助？',
         'api_help_get_key': '• 获取 API 密钥: https://console.anthropic.com',
         'api_help_docs': '• 查看文档: https://docs.anthropic.com',
